@@ -131,7 +131,7 @@ def time_till_metrics(vals, truth_val, expected_dt):
 def validity_nondecreasing_step(series, truth_df, expected_df, *args, **kwargs):
     truth_max = truth_df[expected_df.index < series.name].iloc[:, 0].max()
     num_expected_updates = len(expected_df[expected_df.index < series.name].iloc[:, 0].unique())
-    denom =  (min(num_expected_updates, truth_max) / 5)
+    denom = (min(num_expected_updates, truth_max) / 5)
     if denom == 0:
         return None
     coef = -1 / denom
@@ -683,7 +683,7 @@ def plot_node(
     image_name = 'data_heatmap.png'
     data_df = df_from_s3_csv(prepared_bucket, make_key(data_file, path))
     plt.figure(figsize=(12, 12))
-    plt.pcolormesh(data_df, norm=LogNorm())
+    plt.pcolormesh(data_df, norm=LogNorm(vmin=1))
     len_ind = len(data_df.index)
     len_cols = len(data_df.columns)
     ynum = max(len_ind // 10, 1)
@@ -702,11 +702,10 @@ def plot_node(
     plt.close()
     print('Cleared Heatmap')
 
-
     print("Creating Heatmap of Differences of Releases")
     image_name = 'data_diff_heatmap.png'
     plt.figure(figsize=(12, 12))
-    plt.pcolormesh(data_df.diff(axis=1), norm=LogNorm())
+    plt.pcolormesh(data_df.diff(axis=1), norm=LogNorm(vmin=1))
     len_ind = len(data_df.index)
     len_cols = len(data_df.columns)
     ynum = max(len_ind // 10, 1)
@@ -721,10 +720,9 @@ def plot_node(
     plt.ylabel('Reporting Date (Subject)', fontsize=15)
     save_plt_to_s3(plt, to_bucket, make_key(image_name, path), format='png')
 
-    print('Clearing Heatmap')
+    print('Clearing Heatmap of Differences ')
     plt.close()
-    print('Cleared Heatmap')
-
+    print('Cleared Heatmap of Differences ')
 
     # create an image of the table
     print("Creating Summary Table")
